###############################################################################
# __main__.py
#
# Copyright 2015-2022 Tim Stephenson and contributors
#
#  Licensed under the Apache License, Version 2.0 (the "License"); you may not
#  use this file except in compliance with the License.  You may obtain a copy
#  of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#  License for the specific language governing permissions and limitations under
#  the License.
#
# Entry point for kpctl
#
###############################################################################

from kpctl import kpctl

if __name__ == "__main__":
    kpctl.main()




import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="kpctl",
    version="3.1.3",
    description="Command line interface for managing and executing BPMN",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/tstephen/bpaas",
    author="KnowProcess",
    author_email="info@knowprocess.com",
    license="Apache",
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
    ],
    packages=["kpctl"],
    include_package_data=True,
    install_requires=["cairosvg", "oauthlib", "requests", "requests_oauthlib"],
    entry_points={
        "console_scripts": [
            "kpctl=kpctl.__main__:main",
        ]
    },
)

